# ffprobe-binaries

This package bundles a static `ffprobe` and `ffmpeg` binary and provides a function to get its path from Python. 
This is inteded for use in frameworks with low overhead. 
It can also be used as a workaround for environments without access to "sudo apt get".

# Disclaimer
I did not create or maintain the ffmpeg or ffprove binaries. All credit goes here: https://ffmpeg.org/

## Usage

```python
from ffprobe_binaries import get_ffprobe_path
from ffprobe_binaries import get_ffmpeg_path
from pydub import AudioSegment

AudioSegment.converter = get_ffmpeg_path() #Works with other packages as well
AudioSegment.ffprobe = get_ffprobe_path() #Works with other packages as well


